@@ -8,7 +8,14 @@ import re
 from pyxform.errors import PyXFormError
 from pyxform.question_type_dictionary import QUESTION_TYPE_DICT
 from pyxform.survey_element import SurveyElement
-from pyxform.utils import basestring, node, unicode, default_is_dynamic
+from pyxform.utils import (
+    basestring,
+    node,
+    unicode,
+    default_is_dynamic,
+    BRACKETED_TAG_REGEX,
+    has_dynamic_label,
+)
 
 
 class Question(SurveyElement):
@@ -203,23 +210,27 @@ class MultipleChoiceQuestion(Question):
             itemset_value_ref = "name"
             itemset, file_extension = os.path.splitext(self["itemset"])
             has_media = False
+            has_dyn_label = False
             is_previous_question = bool(re.match(r"^\${.*}$", self.get("itemset")))
 
             if choices.get(itemset):
                 has_media = bool(choices[itemset][0].get("media"))
+                has_dyn_label = has_dynamic_label(choices[itemset], multi_language)
 
             if file_extension in [".csv", ".xml"]:
                 itemset = itemset
                 itemset_label_ref = "label"
             else:
-                if not multi_language and not has_media:
+                if not multi_language and not has_media and not has_dyn_label:
                     itemset = self["itemset"]
                     itemset_label_ref = "label"
                 else:
                     itemset = self["itemset"]
                     itemset_label_ref = "jr:itext(itextId)"
 
-            choice_filter = survey.insert_xpaths(choice_filter, self, True, True)
+            choice_filter = survey.insert_xpaths(
+                choice_filter, self, True, is_previous_question
+            )
             if is_previous_question:
                 path = (
                     survey.insert_xpaths(self["itemset"], self, reference_parent=True)
