@@ -17,6 +17,7 @@ from pyxform.utils import (
     BRACKETED_TAG_REGEX,
     LAST_SAVED_REGEX,
     LAST_SAVED_INSTANCE_NAME,
+    has_dynamic_label,
 )
 from pyxform.errors import PyXFormError, ValidationError
 from pyxform.external_instance import ExternalInstance
@@ -111,16 +112,24 @@ def share_same_repeat_parent(survey, xpath, context_xpath, reference_parent=Fals
     context_parent = is_parent_a_repeat(survey, context_xpath)
     xpath_parent = is_parent_a_repeat(survey, xpath)
     if context_parent and xpath_parent and xpath_parent in context_parent:
-        include_parent = False
-        if not context_parent == xpath_parent and reference_parent:
+        if (not context_parent == xpath_parent and reference_parent) or bool(
+            is_parent_a_repeat(survey, context_parent)
+        ):
             context_shared_ancestor = is_parent_a_repeat(survey, context_parent)
             if context_shared_ancestor == xpath_parent:
                 # Check if context_parent is a child repeat of the xpath_parent
                 # If the context_parent is a child of the xpath_parent reference the entire
                 # xpath_parent in the generated nodeset
-                include_parent = True
                 context_parent = context_shared_ancestor
-        return _get_steps_and_target_xpath(context_parent, xpath_parent, include_parent)
+            elif context_parent == xpath_parent and context_shared_ancestor:
+                # If the context_parent is a child of another
+                # repeat and is equal to the xpath_parent
+                # we avoid refrencing the context_parent and instead reference the shared
+                # ancestor
+                reference_parent = False
+        return _get_steps_and_target_xpath(
+            context_parent, xpath_parent, reference_parent
+        )
     elif context_parent and xpath_parent:
         # Check if context_parent and xpath_parent share a common
         # repeat ancestor
@@ -186,15 +195,17 @@ class Survey(Section):
         root_node_name = self.name
         section_names = []
         for element in self.iter_descendants():
-            if not isinstance(element, Survey) and element.name == root_node_name:
-                raise PyXFormError(
-                    'The name "%s" is the same as the form name. '
-                    "Use a different section name "
-                    '(or change the form name in the "name" column of the settings sheet).'
-                    % element.name
-                )
             if isinstance(element, Section):
                 if element.name in section_names:
+                    if element.name == root_node_name:
+                        # The root node name is rarely explictly set; explain
+                        # the problem in a more helpful way (#510)
+                        raise PyXFormError(
+                            'The name "%s" is the same as the form name. '
+                            "Use a different section name "
+                            '(or change the form name in the "name" column of '
+                            "the settings sheet)." % element.name
+                        )
                     raise PyXFormError(
                         "There are two sections with the name %s." % element.name
                     )
@@ -270,11 +281,16 @@ class Survey(Section):
         instance_element_list = []
         multi_language = isinstance(choice_list[0].get("label"), dict)
         has_media = bool(choice_list[0].get("media"))
+
         for idx, choice in enumerate(choice_list):
             choice_element_list = []
             # Add a unique id to the choice element in case there is itext
             # it references
-            if multi_language or has_media:
+            if (
+                multi_language
+                or has_media
+                or has_dynamic_label(choice_list, multi_language)
+            ):
                 itext_id = "-".join([list_name, str(idx)])
                 choice_element_list.append(node("itextId", itext_id))
 
@@ -283,6 +299,8 @@ class Survey(Section):
                     choice_element_list.append(node(name, unicode(value)))
                 if (
                     not multi_language
+                    and not has_media
+                    and not has_dynamic_label(choice_list, multi_language)
                     and isinstance(value, basestring)
                     and name == "label"
                 ):
@@ -304,7 +322,9 @@ class Survey(Section):
     def _generate_external_instances(element):
         if isinstance(element, ExternalInstance):
             name = element["name"]
-            src = "jr://file/{}.xml".format(name)
+            extension = element["type"].split("-")[0]
+            prefix = "file-csv" if extension == "csv" else "file"
+            src = "jr://{}/{}.{}".format(prefix, name, extension)
             return InstanceInfo(
                 type="external",
                 context="[type: {t}, name: {n}]".format(
@@ -663,7 +683,11 @@ class Survey(Section):
         for list_name, choice_list in self.choices.items():
             multi_language = isinstance(choice_list[0].get("label"), dict)
             has_media = bool(choice_list[0].get("media"))
-            if not multi_language and not has_media:
+            if (
+                not multi_language
+                and not has_media
+                and not has_dynamic_label(choice_list, multi_language)
+            ):
                 continue
             for idx, choice in zip(range(len(choice_list)), choice_list):
                 for name, choice_value in choice.items():
@@ -891,6 +915,23 @@ class Survey(Section):
         is_indexed_repeat = matchobj.string.find("indexed-repeat(") > -1
         indexed_repeat_regex = re.compile(r"indexed-repeat\([^)]+\)")
         function_args_regex = re.compile(r"\b[^()]+\((.*)\)$")
+        instance_regex = re.compile(r"instance\([^)]+\S+")
+
+        def _in_secondary_instance_predicate():
+            """
+            check if ${} expression represented by matchobj
+            is in a predicate for a path expression for a secondary instance
+            """
+
+            # It is possible to have multiple instance in an expression
+            instance_match_iter = instance_regex.finditer(matchobj.string)
+            for instance_match in instance_match_iter:
+                if (
+                    matchobj.start() >= instance_match.start()
+                    and matchobj.end() <= instance_match.end()
+                ):
+                    return True
+            return False
 
         def _relative_path(name):
             """Given name in ${name}, return relative xpath to ${name}."""
@@ -974,6 +1015,8 @@ class Survey(Section):
             )
 
         if _is_return_relative_path():
+            if not use_current:
+                use_current = _in_secondary_instance_predicate()
             relative_path = _relative_path(name)
             if relative_path:
                 return relative_path
