@@ -589,8 +589,6 @@ def workbook_to_json(
     # Rows from the survey sheet that should be nested in meta
     survey_meta = []
 
-    dynamic_default_warning_added = False
-
     # row by row, validate questions, throwing errors and adding warnings
     # where needed.
     for row in survey_sheet:
@@ -622,17 +620,6 @@ def workbook_to_json(
         question_name = row.get(constants.NAME)
 
         question_default = row.get("default")
-        if (
-            default_is_dynamic(question_default, question_type)
-            and not dynamic_default_warning_added
-        ):
-            warnings.append(
-                "This form definition contains dynamic defaults. Not all "
-                "form filling software and versions support dynamic defaults "
-                "so you should test the form with the software version you "
-                "plan to use."
-            )
-            dynamic_default_warning_added = True
 
         if not question_type:
             # if name and label are also missing,
@@ -1294,10 +1281,10 @@ def workbook_to_json(
 
             if "quality" in parameters.keys():
                 if parameters["quality"] not in [
-                    "voice-only",
-                    "low",
-                    "normal",
-                    "external",
+                    constants.AUDIO_QUALITY_VOICE_ONLY,
+                    constants.AUDIO_QUALITY_LOW,
+                    constants.AUDIO_QUALITY_NORMAL,
+                    constants.AUDIO_QUALITY_EXTERNAL,
                 ]:
                     raise PyXFormError("Invalid value for quality.")
 
@@ -1307,6 +1294,24 @@ def workbook_to_json(
             parent_children_array.append(new_dict)
             continue
 
+        if question_type == "background-audio":
+            new_dict = row.copy()
+            parameters = get_parameters(row.get("parameters", ""), ["quality"])
+
+            if "quality" in parameters.keys():
+                if parameters["quality"] not in [
+                    constants.AUDIO_QUALITY_VOICE_ONLY,
+                    constants.AUDIO_QUALITY_LOW,
+                    constants.AUDIO_QUALITY_NORMAL,
+                ]:
+                    raise PyXFormError("Invalid value for quality.")
+
+                new_dict["action"] = new_dict.get("action", {})
+                new_dict["action"].update({"odk:quality": parameters["quality"]})
+
+            parent_children_array.append(new_dict)
+            continue
+
         # TODO: Consider adding some question_type validation here.
 
         # Put the row in the json dict as is:
